@@ -13,8 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
-
 from oslo_log import log as logging
 import oslo_messaging as messaging
 import uuid
@@ -97,6 +95,15 @@ class ConductorManager(object):
         """
         ExtARQ.delete_by_instance(context, instance)
 
+    def arq_apply_patch(self, context, patch_list, valid_fields):
+        """Signal to conductor service to apply patch accelerator requests.
+
+        :param context: request context.
+        :param patch_list: A map from ARQ UUIDs to their JSON patches
+        :param valid_fields: Dict of valid fields
+        """
+        ExtARQ.apply_patch(context, patch_list, valid_fields)
+
     def report_data(self, context, hostname, driver_device_list):
         """Update the Cyborg DB in one hostname according to the
         discovered device list.
@@ -356,7 +363,7 @@ class ConductorManager(object):
 
     def _get_sub_provider(self, context, parent, name):
         old_sub_pr_uuid = str(uuid.uuid3(uuid.NAMESPACE_DNS,
-                                         six.ensure_str(name)))
+                                         str(name)))
         new_sub_pr_uuid = self.placement_client.ensure_resource_provider(
             context, old_sub_pr_uuid,
             name=name, parent_provider_uuid=parent)
@@ -387,7 +394,7 @@ class ConductorManager(object):
         attrs = obj.attribute_list
         resource_class = [i.value for i in attrs if i.key == 'rc'][0]
         traits = [i.value for i in attrs
-                  if six.ensure_str(i.key).startswith("trait")]
+                  if str(i.key).startswith("trait")]
         total = obj.num_accelerators
         rp_uuid = self.provider_report(context, pr_name, resource_class,
                                        traits, total, parent_uuid)
@@ -396,7 +403,7 @@ class ConductorManager(object):
         dep_obj.save(context)
 
     def get_rp_uuid_from_obj(self, obj):
-        return str(uuid.uuid3(uuid.NAMESPACE_DNS, six.ensure_str(obj.name)))
+        return str(uuid.uuid3(uuid.NAMESPACE_DNS, str(obj.name)))
 
     def _delete_provider_and_sub_providers(self, context, rp_uuid):
         rp_in_tree = self.placement_client.get_providers_in_tree(context,
