@@ -22,6 +22,7 @@ sys.path.insert(0, os.path.abspath('../..'))
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
     'sphinx.ext.autodoc',
+    'sphinx.ext.graphviz',
     'openstackdocstheme',
     'oslo_config.sphinxconfiggen',
     'oslo_config.sphinxext',
@@ -41,12 +42,12 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-copyright = u'2013, OpenStack Foundation'
+copyright = '2013, OpenStack Foundation'
 
 # openstackdocstheme options
-repository_name = 'openstack/cyborg'
-bug_project = 'cyborg'
-bug_tag = ''
+openstackdocs_repo_name = 'openstack/cyborg'
+openstackdocs_pdf_link = True
+openstackdocs_use_storyboard = True
 
 config_generator_config_file = '../../tools/config/cyborg-config-generator.conf'
 sample_config_basename = '_static/cyborg'
@@ -64,7 +65,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # -- Options for HTML output --------------------------------------------------
 
@@ -113,8 +114,8 @@ latex_use_xindy = False
 latex_documents = [
     ('index',
      'doc-cyborg.tex',
-     u'Cyborg Documentation',
-     u'OpenStack Foundation', 'manual'),
+     'Cyborg Documentation',
+     'OpenStack Foundation', 'manual'),
 ]
 
 # Example configuration for intersphinx: refer to the Python standard library.
